@@ -1,6 +1,5 @@
 test_that("read_resource() returns a tibble", {
-  skip_if_offline()
-  p <- example_package
+  p <- example_package()
   df <- data.frame("col_1" = c(1, 2), "col_2" = c("a", "b"))
   p <- add_resource(p, "new", df)
 
@@ -10,8 +9,7 @@ test_that("read_resource() returns a tibble", {
 })
 
 test_that("read_resource() allows column selection", {
-  skip_if_offline()
-  p <- example_package
+  p <- example_package()
 
   # Single column
   expect_named(
@@ -69,8 +67,7 @@ test_that("read_resource() allows column selection", {
 })
 
 test_that("read_resource() returns error on column selection not in schema", {
-  skip_if_offline()
-  p <- example_package
+  p <- example_package()
 
   # One column
   expect_error(
@@ -84,7 +81,10 @@ test_that("read_resource() returns error on column selection not in schema", {
   )
   expect_error(
     read_resource(p, "deployments", col_select = "no_such_column"),
-    regexp = "Field names: \"deployment_id\", \"longitude\", \"latitude\", \"start\", and \"comments\".",
+    regexp = paste(
+      "Field names: \"deployment_id\", \"longitude\", \"latitude\", \"start\",",
+      "and \"comments\"."
+    ),
     fixed = TRUE
   )
 
@@ -103,7 +103,10 @@ test_that("read_resource() returns error on column selection not in schema", {
       "deployments",
       col_select = c("no_such_column", "start", "no_such_column_either")
     ),
-    regexp = "Can't find columns \"no_such_column\" and \"no_such_column_either\" in field names.",
+    regexp = paste(
+      "Can't find columns \"no_such_column\" and \"no_such_column_either\" in",
+      "field names."
+    ),
     fixed = TRUE
   )
 })
@@ -117,7 +120,7 @@ test_that("read_resource() returns error on invalid Data Package", {
 
 test_that("read_resource() returns error on invalid resource", {
   skip_if_offline()
-  p <- example_package
+  p <- example_package()
 
   # No such resource
   expect_error(
@@ -140,8 +143,25 @@ test_that("read_resource() returns error on invalid resource", {
     fixed = TRUE
   )
 
+  # Both path or data
+  p_invalid$resources[[1]]$path <- "value"
+  p_invalid$resources[[1]]$data <- "value"
+  expect_error(
+    read_resource(p_invalid, "deployments"),
+    class = "frictionless_error_resource_both_path_data"
+  )
+  expect_error(
+    read_resource(p_invalid, "deployments"),
+    regexp = paste(
+      "Resource \"deployments\" must have a path or data property,",
+      "not both."
+    ),
+    fixed = TRUE
+  )
+
   # No file at path url
-  p_invalid$resources[[1]]$path <- "http://example.com/no_such_file.csv"
+  p_invalid$resources[[1]]$data <- NULL
+  p_invalid$resources[[1]]$path <- "https://example.com/no_such_file.csv"
   expect_error(
     read_resource(p_invalid, "deployments"),
     class = "frictionless_error_url_not_found"
@@ -208,7 +228,7 @@ test_that("read_resource() returns error on invalid resource", {
   )
 
   # No file at schema url
-  p_invalid$resources[[1]]$schema <- "http://example.com/no_schema.json"
+  p_invalid$resources[[1]]$schema <- "https://example.com/no_schema.json"
   expect_error(
     read_resource(p_invalid, "deployments"),
     class = "frictionless_error_url_not_found"
@@ -241,21 +261,21 @@ test_that("read_resource() returns error on invalid resource", {
 })
 
 test_that("read_resource() can read newly added data (ignoring schema)", {
-  p <- example_package
+  p <- example_package()
   df <- data.frame("col_1" = c(1, 2), "col_2" = c("a", "b"))
   p <- add_resource(p, "new", df)
   expect_identical(read_resource(p, "new"), dplyr::as_tibble(df))
 })
 
 test_that("read_resource() can read inline data (ignoring schema)", {
-  p <- example_package
+  p <- example_package()
   expected_resource <- readr::read_csv(
     test_path("data/media.csv"),
     col_types = "ccccc"
   )
   expect_identical(read_resource(p, "media"), expected_resource)
 
-  p$resources[[3]]$data <- "not_a_list" # Media resource
+  p$resources[[3]]$data <- "not_a_list"
   expect_error(
     read_resource(p, "media"),
     regexp = "second argument must be a list",
@@ -264,9 +284,8 @@ test_that("read_resource() can read inline data (ignoring schema)", {
 })
 
 test_that("read_resource() can read local files", {
-  skip_if_offline()
-  p <- example_package
-  resource <- read_resource(p, "deployments") # local resource, remote package
+  p <- example_package()
+  resource <- read_resource(p, "deployments")
 
   p_local <- read_package(
     system.file("extdata", "datapackage.json", package = "frictionless")
@@ -276,13 +295,13 @@ test_that("read_resource() can read local files", {
 
 test_that("read_resource() can read remote files", {
   skip_if_offline()
-  p <- example_package
-  resource <- read_resource(p, "deployments") # local resource, remote package
+  p <- example_package()
+  resource <- read_resource(p, "deployments")
 
   p_remote_resource <- p
   p_remote_resource$resources[[1]]$path <- file.path(
-    "https://github.com/frictionlessdata/frictionless-r",
-    "raw/main/inst/extdata/deployments.csv"
+    "https://raw.githubusercontent.com/frictionlessdata/frictionless-r",
+    "main/inst/extdata/deployments.csv"
   )
   expect_identical(read_resource(p_remote_resource, "deployments"), resource)
 })
@@ -290,13 +309,14 @@ test_that("read_resource() can read remote files", {
 test_that("read_resource() can read safe local and remote Table Schema,
            including YAML", {
   skip_if_offline()
-  p <- example_package
+  p <- example_package()
   resource <- read_resource(p, "deployments")
   p$directory <- "."
+
   # Use a remote path, otherwise schema and path need to share same directory
   p$resources[[1]]$path <- file.path(
-    "https://github.com/frictionlessdata/frictionless-r",
-    "raw/main/inst/extdata/deployments.csv"
+    "https://raw.githubusercontent.com/frictionlessdata/frictionless-r",
+    "main/inst/extdata/deployments.csv"
   )
 
   # Schema is absolute path
@@ -324,8 +344,8 @@ test_that("read_resource() can read safe local and remote Table Schema,
   # Schema is remote path
   p_remote_schema <- p
   p_remote_schema$resources[[1]]$schema <- file.path(
-    "https://github.com/frictionlessdata/frictionless-r",
-    "raw/main/tests/testthat/data/deployments_schema.json"
+    "https://raw.githubusercontent.com/frictionlessdata/frictionless-r",
+    "main/tests/testthat/data/deployments_schema.json"
   )
   expect_identical(read_resource(p_remote_schema, "deployments"), resource)
 
@@ -337,13 +357,14 @@ test_that("read_resource() can read safe local and remote Table Schema,
 
 test_that("read_resource() can read safe local and remote CSV dialect", {
   skip_if_offline()
-  p <- example_package
+  p <- example_package()
   resource <- read_resource(p, "deployments")
   p$directory <- "."
+
   # Use a remote path, otherwise dialect and path need to share same directory
   p$resources[[1]]$path <- file.path(
-    "https://github.com/frictionlessdata/frictionless-r",
-    "raw/main/inst/extdata/deployments.csv"
+    "https://raw.githubusercontent.com/frictionlessdata/frictionless-r",
+    "main/inst/extdata/deployments.csv"
   )
 
   # Dialect is absolute path
@@ -369,8 +390,8 @@ test_that("read_resource() can read safe local and remote CSV dialect", {
   # Dialect is remote path
   p_remote_dialect <- p
   p_remote_dialect$resources[[1]]$dialect <- file.path(
-    "https://github.com/frictionlessdata/frictionless-r",
-    "raw/main/tests/testthat/data/dialect.json"
+    "https://raw.githubusercontent.com/frictionlessdata/frictionless-r",
+    "main/tests/testthat/data/dialect.json"
   )
   expect_identical(read_resource(p_remote_dialect, "deployments"), resource)
 
@@ -381,8 +402,7 @@ test_that("read_resource() can read safe local and remote CSV dialect", {
 })
 
 test_that("read_resource() understands CSV dialect", {
-  skip_if_offline()
-  p <- example_package
+  p <- example_package()
   resource <- read_resource(p, "deployments")
 
   # Create package with non-default dialect properties
@@ -411,8 +431,7 @@ test_that("read_resource() understands CSV dialect", {
 })
 
 test_that("read_resource() understands missing values", {
-  skip_if_offline()
-  p <- example_package
+  p <- example_package()
   resource <- read_resource(p, "deployments")
 
   # Create package with non-default missing values
@@ -426,8 +445,7 @@ test_that("read_resource() understands missing values", {
 })
 
 test_that("read_resource() understands encoding", {
-  skip_if_offline()
-  p <- example_package
+  p <- example_package()
   resource <- read_resource(p, "deployments")
 
   # Create package with non-default encoding
@@ -523,8 +541,7 @@ test_that("read_resource() handles LF and CRLF line terminator characters", {
   #
   # read_delim() however only handles 2 line terminator characters (LF and CRLF)
   # without explicitly indicating them, so dialect$lineTerminator is ignored
-  skip_if_offline()
-  p <- example_package
+  p <- example_package()
   resource <- read_resource(p, "deployments") # This file has LF
 
   p_crlf <- p
@@ -536,7 +553,7 @@ test_that("read_resource() handles LF and CRLF line terminator characters", {
 
 test_that("read_resource() can read compressed files", {
   skip_if_offline()
-  p <- example_package
+  p <- example_package()
   resource <- read_resource(p, "deployments")
 
   # File created in terminal with:
@@ -546,8 +563,8 @@ test_that("read_resource() can read compressed files", {
   p_local_zip$resources[[1]]$path <- test_path("data/deployments.csv.zip")
   p_remote_zip <- p
   p_remote_zip$resources[[1]]$path <- file.path(
-    "https://github.com/frictionlessdata/frictionless-r",
-    "raw/main/tests/testthat/data/deployments.csv.zip"
+    "https://raw.githubusercontent.com/frictionlessdata/frictionless-r",
+    "main/tests/testthat/data/deployments.csv.zip"
   )
 
   # File created in terminal with:
@@ -557,8 +574,8 @@ test_that("read_resource() can read compressed files", {
   p_local_gz$resources[[1]]$path <- test_path("data/deployments.csv.gz")
   p_remote_gz <- p
   p_remote_gz$resources[[1]]$path <- file.path(
-    "https://github.com/frictionlessdata/frictionless-r",
-    "raw/main/tests/testthat/data/deployments.csv.gz"
+    "https://raw.githubusercontent.com/frictionlessdata/frictionless-r",
+    "main/tests/testthat/data/deployments.csv.gz"
   )
 
   expect_identical(read_resource(p_local_zip, "deployments"), resource)
