@@ -1,6 +1,5 @@
 test_that("remove_resource() returns a valid Data Package", {
-  skip_if_offline()
-  p <- example_package
+  p <- example_package()
   expect_no_error(check_package(remove_resource(p, "deployments")))
 })
 
@@ -12,8 +11,7 @@ test_that("remove_resource() returns error on invalid Data Package", {
 })
 
 test_that("remove_resource() returns error when resource not found", {
-  skip_if_offline()
-  p <- example_package
+  p <- example_package()
   expect_error(
     remove_resource(p, "no_such_resource"),
     class = "frictionless_error_resource_not_found"
@@ -25,14 +23,15 @@ test_that("remove_resource() returns error when resource not found", {
   )
   expect_error(
     remove_resource(p, "no_such_resource"),
-    regexp = "Available resources: \"deployments\", \"observations\", and \"media\".",
+    regexp = paste(
+      "Available resources: \"deployments\", \"observations\", and \"media\"."
+    ),
     fixed = TRUE
   )
 })
 
 test_that("remove_resource() removes resource", {
-  skip_if_offline()
-  p <- example_package
+  p <- example_package()
 
   # Remove "deployments", keep "observations" and "media
   p_removed <- remove_resource(p, "deployments")
