@@ -1,6 +1,5 @@
 test_that("resources() returns a character vector of resource names", {
-  skip_if_offline()
-  p <- example_package
+  p <- example_package()
   expect_identical(resources(p), c("deployments", "observations", "media"))
 
   # 1 resource
@@ -14,7 +13,7 @@ test_that("resources() returns a character vector of resource names", {
 })
 
 test_that("resources() returns error if resources have no name", {
-  p <- example_package
+  p <- example_package()
   p$resources[[2]]$name <- NULL
   expect_error(
     resources(p),
